==> fusenshi-0.7.2.tgz: fusenshi-0.7.2/src/net/net.h <==
/*
 * $Id: net.h,v 1.1 2004/04/01 08:53:12 daichi Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.1 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___NET_H
#define ___NET_H

#ifndef __cplusplus
#define __cplusplus
#endif

#include <unistd.h>

#define FUSENSHI_PORT           21006

#define FUSENSHI_NET_PROTO_MAJOR_VERSION    0x00
#define FUSENSHI_NET_PROTO_MINOR_VERSION    0x06

#define FNET_CMD_REQUEST        0x01
#define FNET_CMD_RESPONSE       0x02

#define MAX_EXT_INFO_LENGTH     1024
#define MAX_FUSENSHIDATA_LENGTH (1024 * 1024)

#define NET_CLIENT_USER         "NetClientUser"
#define NET_CLIENT_HOST         "NetClientHost"
#define NET_CLIENT_IP           "NetClientIP"

#include "fusenshiserver.h"
#include "fusenshiclient.h"
#include "fusenshiserverinfo.h"

// ۥ̾Ĺ
#ifdef _SC_HOST_NAME_MAX
extern const long _HOST_NAME_MAX;
#else
# ifdef HOST_NAME_MAX
#  define _HOST_NAME_MAX HOST_NAME_MAX
# else
#  define _HOST_NAME_MAX 255
# endif
#endif

#endif

==> fusenshi-0.7.5.tgz: fusenshi-0.7.5/src/net/net.h <==
/*
 * $Id: net.h,v 1.2 2005/03/23 14:19:01 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.2 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___NET_H
#define ___NET_H

#ifndef __cplusplus
#define __cplusplus
#endif

#include <unistd.h>

#define FUSENSHI_PORT           21006

#define FUSENSHI_NET_PROTO_MAJOR_VERSION    0x00
#define FUSENSHI_NET_PROTO_MINOR_VERSION    0x06

#define FNET_CMD_REQUEST        0x01
#define FNET_CMD_RESPONSE       0x02

/**
 * ۥȾΥѥåȹ¤
 * 
 * [COMMANDTYPE=1byte][MAJORVERSION=1byte][MINORVERSION=1byte]
 * [NICKNAME=?byte][|][HOSTNAME=?byte][0]
 */

#define MAX_HOST_INFO_LENGTH    1024                    // ۥȾκĹUDPѥåѡ1414ޤǤȤ뤳ȡ

/**
 * 䵻ǡΥѥåȹ¤
 * 
 * [HEADER=?byte][DATA=?byte]
 * 
 * HEADERι¤
 * 
 * [LENGTH=4byte][HOSTINFO=LENGTH byte]
 * 
 * HOSTINFOι¤
 * 
 * [NICKNAME=?byte][|][HOSTNAME=?byte][0]
 * 
 * DATAι¤
 * 
 * [LENGTH=4byte][FUSENSHIDATA=LENGTH byte]
 * 
 * FUSENSHIDATAϥꥢ饤Ѥߤ䵻ǡΤΡ
 */
#define MAX_EXT_INFO_LENGTH     MAX_HOST_INFO_LENGTH    // 䵻ոۥȾκĹ
                                                        //ʸߤϡ֥ۥȾפƱ󤷤ʤ
#define MAX_FUSENSHIDATA_LENGTH (1024 * 1024)           // 䵻ǡΤκĹ

#define NET_CLIENT_USER         "NetClientUser"
#define NET_CLIENT_HOST         "NetClientHost"
#define NET_CLIENT_IP           "NetClientIP"

#include "fusenshiserver.h"
#include "fusenshiclient.h"
#include "fusenshiserverinfo.h"

// ۥ̾Ĺ
#ifdef _SC_HOST_NAME_MAX
extern const long _HOST_NAME_MAX;
#else
# ifdef HOST_NAME_MAX
#  define _HOST_NAME_MAX HOST_NAME_MAX
# else
#  define _HOST_NAME_MAX 255
# endif
#endif

#endif
